;LISP NAME:  		on_start.lsp
;PURPOSE: To load BricsCAD custom code
;NOTE: Loads LISP Routines, Sets System Variables
;***********************************
;									
;THIS FILE LAST EDITED ON January 15, 2020  
;									
;***********************************
;Author/Rev. Date:	C.E. Hill May 10, 2019 
;					Initial Production Release
;
;
;REVISION HIGHLIGHTS
;
;Entry Format = Date - Description
;On May 14, 2019 - Changed Variable STARTUP to "0" (Zero) on 
;On May 15, 2019 -  commented out .VLX files incompatible with BricsCAD 2019.
;					Added Autoload for BricsCAD Express Tools. aceutils.des
;On May 28, 2019 - Added (3) LISP routines on date shown in inline comment
;
;******************** Start of Tray Display of System Variables Settings (from gauges.lsp) Section
;
(setvar	"modemacro"
	(strcat	"[*** {UCSbase = "	    "$(getvar,ucsbase)} **"
		" {Base = "		    "$(getvar,insbase)} **"
		" {Elevation = "	    "$(getvar,elevation)} **"
		" {TStyle = "		    "$(getvar,textstyle) @ "
		"$(getvar,textsize)} **"    " {DStyle = "
		"$(getvar,dimstyle)} **"    " {DS/"
		"$(getvar,dimscale) "	    "- LT/"
		"$(getvar,ltscale)} **"	    " {DLF="
		"$(getvar,dimlfac)} **"	    " {IndexCtL = "
		"$(getvar,indexctl)} **"    " {Osnaps ="
		"$(getvar,Osmode)}  ***]"
	       )
)
;
;******************** End of Tray Display Section
;
;******************** Start of *error* Function for Properly Loading LISP Routines
;
;(defun *error* (msg) (princ "error: ") (princ msg) (princ))
;
;******************** Start of AutoLoad and Load Statements for LISP Routines Section
;;; 'Autoload' Statements Per Examples by Steven LaKose from www.waun.org (Worldwide Autodesk Users Group)
;
(autoload "autoload" ' ("autoload"));Added on February 13, 2018 
(autoload "3d_mass" '("3dmass"))
;(autoload "addlines" '("addlines")) ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019 
(autoload "addstr" '("addstr"))
(autoload "alignit" '("ali"))
(autoload "altext" '("altext")) ;Added on October 29, 2015
(autoload "AlignTextToCurveV1-2" '("atcc")) ;Added on August 02, 2017
;(autoload "area" '("area")) ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
(autoload "arrow" '("aaa"))
(autoload "ats" '("ats"))
(autoload "attdef2text" '("attd"))
 ;(load "attinc")
(autoload "attinc" '("attinc"))
(autoload "AttModSuiteV1-1" '("roatt"))
;(autoload "attsyncall" '("attsyncall"))  ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
 ;(load "backgroundchanger")
(autoload "backgroundchanger"
	  '("BGGrey" "BGWhite" "BGBlack" "bgt")
)
(autoload "AutoBlockBreakV1-8" '("ABB")) ; Added on May 28, 2019
(autoload "BFindV2-0" '("BFind"))
(autoload "BlockRename" '("BlockRename"))
(autoload "BreakObjects23" '("Mybreak")); Updated to "...23" version on June 06, 2019 
(autoload "BTC" '("BTC"))
(autoload "BurstUpgradedV1-7" '("PBURST")) ; Added on May 28, 2019 
(autoload "CA" '("CA"))
(autoload "CADPL-Pack-v1.lsp" '("ada")) ;Added on April 13, 2018
(autoload "CENDIM" '("CENDIM"))
 ;(load "ChBlkTxt")
(autoload "ChBtextA" '("CBA"))
;(autoload "chmtc" '("chmtc"))  ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
;(autoload "chz20" '("chz20")) ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
(autoload "CopySwapTextV1-7" '("CTX")) ; Updated on January 19, 2018
(autoload "ctr" '("CTR"))
(autoload "CSViewport" '("CCVV"))
(autoload "DELPAGESETUPS" '("delpagesetups"))
(autoload "dimiso" '("dimiso")) ;Added on May 04, 2017 
(autoload "dimse" '("dimse"))
(autoload "dimlinechange" '("DLC"))
(autoload "DSS" '("DSS"))
(autoload "DateToAtt" '("DTAT")) ;Added on July 08, 2019 - Updates Attribute to current data (Format as MM/DD/YY)
(autoload "DTCurveV2-9" '("DTCurve")) ;Added on February 13, 2018
(autoload "EASD" '("EASD"))
(autoload "ECD" '("ECD"))
(load "Acetutil.des")
(princ)
(autoload "fast" '("FAST"))
(autoload "fx" '("FX"))
(autoload "GAUGES" '("GAUGES"))
;(autoload "grd" '("grd"))  ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
(autoload "hose" '("HOSE"))
(autoload "howfar" '("HH"))
(autoload "HSS" '("HSS"))
(autoload "I-Arial_N" '("III"))
;(autoload "innb" '("innb"))  ; commented out: .VLX files are incompatible with BricsCAD 2019 - May 15, 2019
(autoload "isodim" '("IOD"))
(autoload "layer_creator" '("LC"))
(autoload "LCK" '("LCK"))
(autoload "LEQ" '("LEQ"))  ;Added on December 07, 2015 - For CADWorx Plant Equip Tagging 
(autoload "linklists" '("YYY"))
(autoload "LST" '("LST"))
(autoload "LayerExtract" '("LX")) ; Added on August 19, 2013
(autoload "LZE" '("LZE"))
(autoload "MacAttV3-1" '("MacAtt")) ; Added on July 24, 2019  
(autoload "MTEXTMASK" '("MTM"))
(autoload "normall" '("normall")) ; Added on July 19, 2017 
(autoload "NumIncV3-8" '("NUMINC"))
(autoload "ObjectAlignV1-5" '("OA")) ; Added on January 15, 2020 
(autoload "on" '("on"))
(autoload "quickgroup" '("QQ"))
(autoload "quickungroup" '("QQW"))
(autoload "patt" '("patt"))
(autoload "pipend" '("pipend"))
(autoload "PrefixSuffixLayerV1-1" '("PSLA")) ; Added on May 28, 2019 
(autoload "psfixtxt" '("PSFIXTXT"))
(autoload "pstyle" '("PTY")) ; Added on November 23, 2015 - Imports page setups
(autoload "RotateVW" '("RTV")) ; Added on March 31, 2020 - Rotate entities via reference    
(autoload "S-Deck" '("SDK"))
(autoload "saoo" '("SAOO")) ; Added on September 20, 2017 - Snap Toggle
(autoload "sent" '("SENT"))
(autoload "snake" '("SNAKE"))
(autoload "StealV1-8" '("StealV1-8"))
(autoload "stl" '("STL"))
(autoload "tchange" '("TCH"))
(autoload "TDD" '("TDD")) ; Added on May 23, 2017  - Transfers Dimension Styles including Tolerances
(autoload "Toggle_Theme" '("TT")) ; Added on November 13, 2019   - Toggles User Interface and Background Colors
(autoload "TR2L" '("TR2L")) ; Added on November 23, 2015 - Convert Trace to Line
(autoload "transfer" '("TX"))
(autoload "UPA" '("UPA"))
(autoload "Undynamic" '("UNDY")) ; Added on September 06, 2019  - Convert Dynamic Block to Static Block with Added Suffix Number to Name
(autoload "Unmask" '("UNMASK")) ; Added on September 18, 2019  - Remove Background Mask from Block Attribute Fields
(autoload "UpdateTitleblockV1-9" '("UTB"))
(autoload "vp2ms" '("VP2MS"))
(autoload "vp-outline" '("VV"))
(autoload "wd" '("WD"))
(autoload "ZZ" '("ZZ"))
 ;
 ;******************** End of AutoLoad and Load Statements for LISP Routines Section
 ;
 ;******************** Start of System Variables Setting Section
;;; Code Per Tom Beauford from www.waun.org (Worldwide Autodesk Users Group)
 ;
(if (/= (getvar "angbase") 0)
  (progn (setvar "angbase" 0)
	 (princ "\nSet base angle to 0 (East).")
  )
)
(if (/= (getvar "angdir") 0)
  (progn (setvar "angdir" 0)
	 (princ "\nSet angle direction to counterclockwise.")
  )
)
(if (/= (getvar "aunits") 0)
  (progn (setvar "aunits" 0)
	 (princ "\nAngle measure is in Decimal Degrees.")
  )
)
(if (/= (getvar "auprec") 3)
  (progn (setvar "auprec" 3)
	 (princ "\nSet angle precision to d.ddd\".")
  )
)
(if (/= (getvar "blockeditlock") 0)
  (progn (setvar "blockeditlock" 0)
	 (princ "\nSet blocks as editable.")
  )
)
(if (/= (getvar "cursorsize") 100)
  (progn (setvar "cursorsize" 100)
	 (princ "\nSet Cursorsize to 100%.")
  )
)
(if (/= (getvar "dimzin") 3)
  (progn (setvar "dimzin" 3)
	 (princ "\nNo zero inch suppression in fractional dimensions.")
  )
)
(if (/= (getvar "draworderctl") 3)
  (progn (setvar "draworderctl" 3)
	 (princ "\nFull Draworder Display.")
  )
)
(if (/= (getvar "explmode") 1)
  (progn (setvar "explmode" 1)
	 (princ "\nExplode nonuniformly scaled (NUS) blocks.")
  )
)
(if (/= (getvar "extnames") 1)
  (progn (setvar "extnames" 1)
	 (princ "\nAllow long symbol names.")
  )
)
(if (/= (getvar "filedia") 1)
  (progn (setvar "filedia" 1)
	 (princ "\nDisplay dialog boxes.")
  )
)
(if (/= (getvar "fillmode") 1)
  (progn (setvar "fillmode" 1)
	 (princ "\nFill solids & plines and display hatches.")
  )
)
(if (/= (getvar "hidexrefscales") 1)
  (progn (setvar "hidexrefscales" 1)
	 (princ "\nHide xref scales in scale list.")
  )
)
(if (/= (getvar "hpassoc") 1)
  (progn (setvar "hpassoc" 1)
	 (princ "\nHatch associated with boundary.")
  )
)
(if (/= (getvar "HpDrawOrder") 1)
  (progn
    (setvar "HpDrawOrder" 1)
    (princ
      "\nThe hatch or fill is sent to the back of all other objects."
    )
  )
)
(if (/= (getvar "hpgaptol") 0)
  (progn (setvar "hpgaptol" 0)
	 (princ "\nHatch pattern gap tolerence.")
  )
)
(if (/= (getvar "insunits") 0)
  (progn (setvar "insunits" 0)
	 (princ
	   "\nSet units for inserting from Design Center to Unspecified."
	 )
  )
)
(if (/= (getvar "insunitsdefsource") 0)
  (progn (setvar "insunitsdefsource" 0)
	 (princ
	   "\nSets source content units value when INSUNITS is set to 0."
	 )
  )
)
(if (/= (getvar "insunitsdeftarget") 0)
  (progn (setvar "insunitsdeftarget" 0)
	 (princ
	   "\nSets target drawing units value when INSUNITS is set to 0."
	 )
  )
)
(if (/= (getvar "lunits") 2)
  (progn (setvar "lunits" 2)
	 (princ "\nSet linear units to decimal.")
  )
)
(if (/= (getvar "luprec") 4)
  (progn (setvar "luprec" 4)
	 (princ "\nSet number of decimal places displayed.")
  )
)
(if (/= (getvar "lwdefault") 30)
  (progn (setvar "lwdefault" 30)
	 (princ
	   "\nSet default lineweight to 30 hundredths of a millimeter."
	 )
  )
)
(if (< (getvar "maxactvp") 64)
  (progn (setvar "maxactvp" 64)
	 (princ
	   "\nMAXACTVP: set max # of viewports that can be active to 64."
	 )
  )
)
(if (/= (getvar "mirrtext") 0)
  (progn (setvar "mirrtext" 0) (princ "\nMirror text."))
)
(if (/= (getvar "msltscale") 1)
  (progn
    (setvar "msltscale" 1)
    (princ
      "\nLinetypes displayed on the Model tab are scaled by the annotation scale."
    )
  )
)
(if (/= (getvar "mtexted") "internal")
  (progn (setvar "mtexted" "internal")
	 (princ "\nEdit with the In-Place Text Editor.")
  )
)
(if (/= (getvar "mtextfixed") 2)
  (progn
    (setvar "mtextfixed" 2)
    (princ
      "\nResize Text that is difficult to read so that you can edit it."
    )
  )
)
(if (/= (getvar "obscuredltype") 0)
  (progn (setvar "obscuredltype" 0)
	 (princ "\nLinetypes Visible! OBSCUREDLTYPE")
  )
)
(if (/= (getvar "offsetgaptype") 0)
  (progn
    (setvar "offsetgaptype" 0)
    (princ
      "\nFills the offset gaps by extending the polyline segments: OFFSETGAPTYPE"
    )
  )
)
(if (/= (getvar "osmode") 16383)
  (progn (setvar "osmode" 16383)
	 (princ
	   "\nAll 2D object snaps are active. OSMODE"
	 )
  )
)
(if (/= (getvar "osnapcoord") 1)
  (progn (setvar "osnapcoord" 1)
	 (princ
	   "\nKeyboard entry overrides object snap settings. OSNAPCOORD"
	 )
  )
)
(if (/= (logand (getvar "osoptions") 1) 1)
  (progn (setvar "osoptions" (1+ (getvar "osoptions")))
	 (princ "\nObject snaps ignore hatch objects. OSOPTIONS")
  )
)
(if (/= (getvar "peditaccept") 1)
  (progn
    (setvar "peditaccept" 1)
    (princ
      "\nSuppress the Object Selected Is Not a Polyline prompt in PEDIT. PEDITACCEPT")
  )
)
(if (/= (getvar "pellipse") 0)
  (progn (setvar "pellipse" 0)
	 (princ "\nCreate true ellipse objects. PELLIPSE")
  )
)
(if (/= (getvar "pickbox") 16)
  (progn (setvar "pickbox" 16)
	 (princ "\nSet the pickbox arperture size. PICKBOX")
  )
)
(if (/= (getvar "pickfirst") 1)
  (progn (setvar "pickfirst" 1)
	 (princ "\nPick before command. PICKFIRST")
  )
)
(if (/= (getvar "pickstyle") 1)
  (progn (setvar "pickstyle" 1)
	 (princ
	   "\n<Group on> Associative hatch selection off. PICKSTYLE"
	 )
  )
)
(if (/= (getvar "plinetype") 2)
  (progn (setvar "plinetype" 2)
	 (princ "\nPlines set to lwpolylines. PLINETYPE")
  )
)
(if (/= (getvar "plinewid") 0)
  (progn (setvar "plinewid" 0)
	 (princ "\nPline width set to 0. PLINEWID")
  )
)
(if (/= (getvar "regenmode") 1)
  (progn (setvar "regenmode" 1)
	 (princ "\nRegen without prompting. REGENMODE")
  )
)
(if (/= (getvar "SaveFidelity") 0)
  (progn
    (setvar "SaveFidelity" 0)
    (princ
      "\nSaved without visual fidelity for annotative objects. SaveFidelity"
    )
  )
)
(if (or (= 0 (getvar "SAVETIME")) (> (getvar "SAVETIME") 20))
  (progn (setvar "Savetime" 15)
	 (princ "\nAutosave every 15 minutes.")
  )
)
(if (/= (getvar "selectionpreview") 3)
  (progn
    (setvar "selectionpreview" 3)
    (princ
      "\nHighlight objects when the cursor rolls over them. SELECTIONPREVIEW"
    )
  )
)
(if (/= (getvar "SDI") 0)
  (progn (setvar "SDI" 0)
	 (princ "\nSwitch to multiple document mode.")
  )
)
(if (/= (getvar "shortcutmenu") 27)
  (progn (setvar "shortcutmenu" 27)
	 (princ "\nTurn on time sensitive right-click.")
  )
)
(if (/= (getvar "startup") 0)
  (progn (setvar "startup" 0)
	 (princ "\nDisabled the \"Create New Drawing\" dialog box.") ; on 5-14-2019 - changed to '0' from '1'
  )
)
(if (/= (getvar "tabmode") 0)
  (progn (setvar "tabmode" 0)
	 (princ "\nTurns off Tablet mode.")
  )
)
(if (/= (getvar "TextEval") 0)
  (progn (setvar "TextEval" 0)
	 (princ
	   "\nPrompts for text & attribute values are taken literally."
	 )
  )
)
(if (/= (getvar "tstackalign") 1)
  (progn (setvar "tstackalign" 1)
	 (princ "\nCenter the vertical alignment of stacked text.")
  )
)
(if (/= (getvar "ucsicon") 3)
  (progn (setvar "ucsicon" 3) (princ "\nUCSICON On at Origin!"))  ; on 9-30-2019 - changed to '1' from '3'
)
(if (/= (getvar "WmfBkGnd") 0)
  (progn (setvar "WmfBkGnd" 0)
	 (princ "\nSet WMF background transparent.")
  )
)
(if (/= (getvar "WmfForeGnd") 0)
  (setvar "WmfForeGnd" 0)
)
(if (/= (getvar "xrefctl") 0)
  (progn (setvar "xrefctl" 0) (princ "\nXref log files Off!"))
)
(if (/= (getvar "Zoomwheel") 0)
  (progn (setvar "Zoomwheel" 0)
	 (princ "\nScroll wheel forward to zoom in: Zoomwheel")
  )
)
;
;******************** End of System Variables Setting Section
;
(princ "\n\"BricsCAD customized startup routine on_start.lsp by Innophos\" is loaded: Go for Launch!")
(princ)